Unreleased changes
------------------


Version 0
---------

0.2.0 / 2026-02-03
~~~~~~~~~~~~~~~~~~

* First effective version

0.1.0 / 2024-06-03
~~~~~~~~~~~~~~~~~~
* Project generated using the cookiecutter template from
  https://git.km3net.de/templates/python-project
